# Changelog

## 1.4.1 (2025-10-11)

Full Changelog: [v1.4.0...v1.4.1](https://github.com/deeprails/deeprails-sdk-python/compare/v1.4.0...v1.4.1)

### Chores

* **internal:** detect missing future annotations with ruff ([c0b084c](https://github.com/deeprails/deeprails-sdk-python/commit/c0b084c0f0e71a600274186c30902246aa3816d1))

## 1.4.0 (2025-10-10)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** manual updates ([b6beebc](https://github.com/deeprails/deeprails-sdk-python/commit/b6beebca6323df5ae35ef30d419d96c831bebbb8))

## 1.3.0 (2025-10-08)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** adding code samples ([c7f7565](https://github.com/deeprails/deeprails-sdk-python/commit/c7f7565abd00233d22d9c11a5b2c977414e03439))
* **api:** manual updates ([145946a](https://github.com/deeprails/deeprails-sdk-python/commit/145946a049fb29bff01df6763248330f4d0030ad))

## 1.2.0 (2025-10-07)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** manual updates ([db3e710](https://github.com/deeprails/deeprails-sdk-python/commit/db3e710d267ccf8d99aa214348846e20b6484db6))

## 1.1.0 (2025-10-07)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([e55683b](https://github.com/deeprails/deeprails-sdk-python/commit/e55683b590ff636e7c876a172c22c52c3208ceda))
* **api:** manual updates ([3309c85](https://github.com/deeprails/deeprails-sdk-python/commit/3309c859f9e67579bcd9d2f2d82ed7d67609dca8))


### Chores

* update SDK settings ([9b65ba6](https://github.com/deeprails/deeprails-sdk-python/commit/9b65ba6e8675011f89f035d608a404d7c1d50453))
* update SDK settings ([957c361](https://github.com/deeprails/deeprails-sdk-python/commit/957c3611f3baf773270a491c66a28b8eeb66d671))
* update SDK settings ([3dcb5cb](https://github.com/deeprails/deeprails-sdk-python/commit/3dcb5cb41ee6c1008f66dace32125fd38626bdca))
* update SDK settings ([b283586](https://github.com/deeprails/deeprails-sdk-python/commit/b28358658ea8cbea0d2cb679343a9cf1c342fbd2))

## 1.0.0 (2025-10-07)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/deeprails/deeprails-python-sdk/compare/v0.0.1...v1.0.0)

### Chores

* update SDK settings ([3dcb5cb](https://github.com/deeprails/deeprails-python-sdk/commit/3dcb5cb41ee6c1008f66dace32125fd38626bdca))
* update SDK settings ([b283586](https://github.com/deeprails/deeprails-python-sdk/commit/b28358658ea8cbea0d2cb679343a9cf1c342fbd2))
